//	NPBGain.cpp - Gain object, derived from NPBPluginBase.
//			      Currently needs a vertical slider...
//	--------------------------------------------------------------------------
//	This file is part of 'Niall's Pedal Board', a simple ASIO VST host.
//	Copyright (C) 2004-2005  Niall Moody
//	
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//	
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//	
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//	
//	--------------------------------------------------------------------------
//	
//	You can e-mail me at niallmoody@yahoo.co.uk if you want.
//	
//	--------------------------------------------------------------------------

#include "NPBGain.h"

Factory<NPBPluginBase, NPBGain> NPBGain::myFactory;

NPBGain::NPBGain(NPBPluginOrganiser *parent):NPBPluginBase(parent)
{
	Colour tempc(87, 176, 205);
	Colour temp2(50, 137, 166);

	addAndMakeVisible(Gain = new VerticalSlider(T("Gain")));
	Gain->setRange(0.0, 2.0);
	Gain->setSize(55, 115);
	Gain->setValue(1.0f);

	setSize(75, 125);
}

NPBGain::~NPBGain()
{
	
}

void NPBGain::paint(Graphics& g)
{
	g.setColour(Colour::greyLevel(0.4f));
    RectangleList visible;
    getVisibleArea(visible, false);
    visible.fill(g);

	SolidColourBrush brush(Parent->getPlugColour());
	g.setBrush(&brush);
	g.fillAll();

	g.setColour (Colours::black.withAlpha (0.25f));
    g.drawRect (0, 0, getWidth(), getHeight());
	g.setColour (Colours::black.withAlpha (0.125f));
    g.drawRect (1, 1, (getWidth()-2), (getHeight()-2));
}

void NPBGain::actionListenerCallback(const String& m)
{
	
}

void NPBGain::ProcessAudio(float **input, float **output, int numsamples)
{
	int i, j;

	for(i=0;i<NumChannels;i++)
	{
		for(j=0;j<numsamples;j++)
		{
			output[i][j] = (input[i][j] * (float)Gain->getValue());
		}
	}
}

void NPBGain::resized()
{
    /*Edit->setTopLeftPosition(5, 5);
    Mappings->setTopLeftPosition(5, 30);
    Bypass->setTopLeftPosition(5, 95);*/
	Gain->setTopLeftPosition(10, 10);
}

void NPBGain::mouseDown(const MouseEvent& e)
{
	if(e.mods.isRightButtonDown())
	{
		PopupMenu menu;
		menu.addItem(1, "Delete this Plugin");

		const int result = menu.show();

		switch(result)
		{
			case 1:
				NeedsDeleted = true; //**necessary for the plugin to be deleted**
				getParentComponent()->postCommandMessage(DELETE_THIS_PLUGIN);
				break;
		}
	}
}
