//	NPBGain.h - Gain object, derived from NPBPluginBase.
//			    Currently needs a vertical slider...
//	--------------------------------------------------------------------------
//	This file is part of 'Niall's Pedal Board', a simple ASIO VST host.
//	Copyright (C) 2004-2005  Niall Moody
//	
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//	
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//	
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//	
//	--------------------------------------------------------------------------
//	
//	You can e-mail me at niallmoody@yahoo.co.uk if you want.
//	
//	--------------------------------------------------------------------------

#ifndef NPBGAIN_H_
#define NPBGAIN_H_

#include "NPBPluginBase.h"
#include "VerticalSlider.h"

///	Simple plugin to provide a gain control for the signal path.
class NPBGain : public NPBPluginBase,
					   ActionListener
{
  public:
	///	Constructor.
	NPBGain(NPBPluginOrganiser *parent);
	///	Destructor.
	~NPBGain();

	///	Draws the background.
	/*!
		Uses the parent NPBPluginOrganiser's pluginColour.
	 */
	void paint(Graphics& g);
	///	Not used.
	void actionListenerCallback(const String& m);

	///	Processes the block of audio presented in input (just altering the gain, really).
	void ProcessAudio(float **input, float **output, int numsamples);

	///	Used to position the Gain slider correctly.
	void resized();
	///	Used to detect when the right mouse button menu should be displayed.
	void mouseDown(const MouseEvent& e);

	///	Returns the number of parameters this plugin has (i.e. 1).
	/*!
		Used by NPBPluginOrganiser for saving plugin patches/configurations.
	 */
	long getNumParameters() {return 1;};
	///	Returns the value of the indexed parameter.
	/*!
		Used by NPBPluginOrganiser for saving plugin patches/configurations.
	 */
	float getParameter(long index) {return (float)Gain->getValue();};
	///	Sets the value of the indexed parameter.
	/*!
		Used by NPBPluginOrganiser for saving plugin patches/configurations.
	 */
	void setParameter(long index, float val) {Gain->setValue(val);};

	///	Factory to construct a new copy of this class.
	static Factory<NPBPluginBase, NPBGain> myFactory;
  private:
	VerticalSlider *Gain;
};

#endif
