//	NPBMono2Stereo.h - Simple object to convert the o/p of mono plugins to 
//					   stereo.
//	--------------------------------------------------------------------------
//	This file is part of 'Niall's Pedal Board', a simple ASIO VST host.
//	Copyright (C) 2004-2005  Niall Moody
//	
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//	
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//	
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//	
//	--------------------------------------------------------------------------
//	
//	You can e-mail me at niallmoody@yahoo.co.uk if you want.
//	
//	--------------------------------------------------------------------------

#ifndef NPBMONO2STEREO_H_
#define NPBMONO2STEREO_H_

#include "NPBPluginBase.h"

///	Simple plugin to copy the left channel of the input to the left *and* right channels of the output.
/*!
	(because some really cool plugins (e.g. pvTranspose) are mono only)
 */
class NPBMono2Stereo : public NPBPluginBase
{
  public:
	///	Constructor.
	NPBMono2Stereo(NPBPluginOrganiser *parent);
	///	Destructor.
	~NPBMono2Stereo();

	///	Draws the background.
	/*!
		Uses the parent NPBPluginOrganiser's pluginColour attribute.  Also
		draws the text 'Mono2Stereo'
	 */
	void paint(Graphics& g);
	///	To detect whether the right mouse button menu should be displayed.
	void mouseDown(const MouseEvent& e);

	///	Does the appropriate audio processing.
	void ProcessAudio(float **input, float **output, int numsamples);

	///	Factory to construct an instance of this class.
	static Factory<NPBPluginBase, NPBMono2Stereo> myFactory;
};

#endif
