//	NPBPluginEditor.h - Simple editor for plugins which don't have
//					    their own gui.
//	--------------------------------------------------------------------------
//	This file is part of 'Niall's Pedal Board', a simple ASIO VST host.
//	Copyright (C) 2004-2005  Niall Moody
//	
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//	
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//	
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//	
//	--------------------------------------------------------------------------
//	
//	You can e-mail me at niallmoody@yahoo.co.uk if you want.
//	
//	--------------------------------------------------------------------------

#ifndef NPBPLUGINEDITOR_H_
#define NPBPLUGINEDITOR_H_

//because we use it in NPBPlugin.h
class NPBPluginEditor;

#ifndef NPBPLUGIN_H_
#include "NPBPlugin.h"
#endif

class NPBPluginEditorContent;

///	Simple editor for VST plugins (NPBPlugin) which don't provide their own editor.
/*!
	Basically just creates a slider for every parameter.
 */
class NPBPluginEditor : public DialogWindow
{
  public:
	///	Constructor.
	/*!
		\param plugin Pointer to the actual plugin (used to determine the name
		of the plugin).
		\param parent Pointer to our the NPBPlugin which this editor
		represents.
		\param col The background colour of the window.
	 */
	NPBPluginEditor(AEffect *plugin, NPBPlugin *parent, Colour col);
	///	Destructor.
	~NPBPluginEditor();

	///	Called to inform the window that the Mix parameter has changed.
	/*!
		(hence the Mix Slider in NPBPluginEditorContent should be updated)
	 */
	void setMix(float val);
	///	Called to inform the window that that a plugin parameter has changed.
	/*!
		(hence the appropriate Slider in NPBPluginEditorContent should be
		updated)
	 */
	void setParameter(long index, float val);
  private:
	NPBPlugin *Parent;
};

///	The Content Component for NPBPluginEditor.
class NPBPluginEditorContent : public Component,
								 ActionListener,
								 ChangeListener
{
  public:
	///	Constructor.
	/*!
		\param plugin Pointer to the actual plugin.
		\param parent Pointer to our the NPBPlugin which this editor
		represents.
	 */
	NPBPluginEditorContent(AEffect *plugin, NPBPlugin *parent);
	///	Destructor.
	~NPBPluginEditorContent();

	///	Called when the user selects a new program from Programs.
	/*!
		Basically we just update the sliders and inform the plugin when this
		happens.
	 */
	void actionListenerCallback(const String& m);
	///	Called whenever a Slider has been moved.
	/*!
		Used to inform the plugin when the user has altered a parameter.
	 */
	void changeListenerCallback(void *objectThatHasChanged);

	///	Called to inform the window that the Mix parameter has changed.
	/*!
		(hence the Mix Slider should be updated)
	 */
	void setMix(float val) {Mix->setValue(val);};
	///	Called to inform the window that that a plugin parameter has changed.
	/*!
		(hence the appropriate Slider in Sliders should be updated)
	 */
	void setParameter(long index, float val);
  private:
	AEffect *Plugin;
	NPBPlugin *Parent;

	ComboBox *Programs;
	Label *MixLabel;
	Slider *Mix;

	Label **Labels;
	Slider **Sliders;
	Label **Units;
};

#endif
