///	PluginOrganiser.cpp - The main workspace of the program.
///	--------------------------------------------------------------------------
///	This file is part of 'Niall's Pedal Board', a simple ASIO VST host.
///	Copyright (C) 2005  Niall Moody
///	
///	This program is free software; you can redistribute it and/or modify
///	it under the terms of the GNU General Public License as published by
///	the Free Software Foundation; either version 2 of the License, or
///	(at your option) any later version.
///	
///	This program is distributed in the hope that it will be useful,
///	but WITHOUT ANY WARRANTY; without even the implied warranty of
///	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
///	GNU General Public License for more details.
///	
///	You should have received a copy of the GNU General Public License
///	along with this program; if not, write to the Free Software
///	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
///	
///	--------------------------------------------------------------------------
///	
///	You can e-mail me at niallmoody@yahoo.co.uk if you want.
///	
///	--------------------------------------------------------------------------

#include "../NPBWindow.h"
#include "PluginOrganiser.h"
#include "../ComponentFactory.h"
#include "../NPBPluginOrganiser.h"

//--static member variables must be declared--
int PluginOrganiser::backRed = 250;
int PluginOrganiser::backGreen = 235;
int PluginOrganiser::backBlue = 215;
int PluginOrganiser::plugRed = 144;
int PluginOrganiser::plugGreen = 238;
int PluginOrganiser::plugBlue = 144;
int PluginOrganiser::plugButtonRed = 87;
int PluginOrganiser::plugButtonGreen = 176;
int PluginOrganiser::plugButtonBlue = 205;

///---------------------------------------------------------------------------
PluginOrganiser::PluginOrganiser(ComponentFactory *factory, Component **windowComponent):
FactoryObject(factory, windowComponent)
{
	//--Set default values to allow for the user missing out on an attribute.--
	x = 10;
	y = 60;
	xRel = -1;
	yRel = -1;
	width = -20;
	height = -95;
	widthRel = -1;
	heightRel = -1;

	//Register this object with the factory.
	factory->registerObject(this, String("pluginOrganiser"));

	//Register all it's attributes with the factory.
	factory->registerIntAttribute(this, String("backColour_red"), &PluginOrganiser::setBackColourRed);
	factory->registerIntAttribute(this, String("backColour_green"), &PluginOrganiser::setBackColourGreen);
	factory->registerIntAttribute(this, String("backColour_blue"), &PluginOrganiser::setBackColourBlue);
	factory->registerIntAttribute(this, String("plugColour_red"), &PluginOrganiser::setPlugColourRed);
	factory->registerIntAttribute(this, String("plugColour_green"), &PluginOrganiser::setPlugColourGreen);
	factory->registerIntAttribute(this, String("plugColour_blue"), &PluginOrganiser::setPlugColourBlue);
	factory->registerIntAttribute(this, String("plugButtonColour_red"), &PluginOrganiser::setPlugButtonColourRed);
	factory->registerIntAttribute(this, String("plugButtonColour_green"), &PluginOrganiser::setPlugButtonColourGreen);
	factory->registerIntAttribute(this, String("plugButtonColour_blue"), &PluginOrganiser::setPlugButtonColourBlue);
}

///---------------------------------------------------------------------------
void PluginOrganiser::create()
{
	NPBWindow *window;
	NPBPluginOrganiser *tempComp;
	Colour tempcol1(backRed, backGreen, backBlue);
	Colour tempcol2(plugRed, plugGreen, plugBlue);
	Colour tempcol3(plugButtonRed, plugButtonGreen, plugButtonBlue);

	window = static_cast<NPBWindow *>(factory->getWindow());

	window->addAndMakeVisible(tempComp = new NPBPluginOrganiser());
	tempComp->setBackColour(tempcol1);
	tempComp->setPlugColour(tempcol2);
	tempComp->setPlugButtonColour(tempcol3);

	*windowComponent = tempComp;
}

///---------------------------------------------------------------------------
void PluginOrganiser::setBackColourRed(int val)
{
	backRed = val;
}

///---------------------------------------------------------------------------
void PluginOrganiser::setBackColourGreen(int val)
{
	backGreen = val;
}

///---------------------------------------------------------------------------
void PluginOrganiser::setBackColourBlue(int val)
{
	backBlue = val;
}

///---------------------------------------------------------------------------
void PluginOrganiser::setPlugColourRed(int val)
{
	plugRed = val;
}

///---------------------------------------------------------------------------
void PluginOrganiser::setPlugColourGreen(int val)
{
	plugGreen = val;
}

///---------------------------------------------------------------------------
void PluginOrganiser::setPlugColourBlue(int val)
{
	plugBlue = val;
}

///---------------------------------------------------------------------------
void PluginOrganiser::setPlugButtonColourRed(int val)
{
	plugButtonRed = val;
}

///---------------------------------------------------------------------------
void PluginOrganiser::setPlugButtonColourGreen(int val)
{
	plugButtonGreen = val;
}

///---------------------------------------------------------------------------
void PluginOrganiser::setPlugButtonColourBlue(int val)
{
	plugButtonBlue = val;
}
